==> jc-1.4.0.tar.gz: javax/imageio/ImageIO__24WriterSuffixFilter.h <==
// final class javax.imageio.ImageIO$WriterSuffixFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5449b10f77b076ec javax_imageio_ImageIO__24WriterSuffixFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_
#define _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods	javax_imageio_ImageIO__24WriterSuffixFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs {
	struct _jc_java_lang_String$object	*fileSuffix;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs {
    _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs	javax_imageio_ImageIO__24WriterSuffixFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs	javax_imageio_ImageIO__24WriterSuffixFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object {
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype _jc_javax_imageio_ImageIO__24WriterSuffixFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24WriterSuffixFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24WriterSuffixFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageIO__24WriterSuffixFilter.h <==
// final class javax.imageio.ImageIO$WriterSuffixFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5449b10f77b076ec javax_imageio_ImageIO__24WriterSuffixFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_
#define _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24WriterSuffixFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vmethods	javax_imageio_ImageIO__24WriterSuffixFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs {
	struct _jc_java_lang_String$object	*fileSuffix;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs {
    _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_refs	javax_imageio_ImageIO__24WriterSuffixFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24WriterSuffixFilter$sub_nonrefs	javax_imageio_ImageIO__24WriterSuffixFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24WriterSuffixFilter$object {
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24WriterSuffixFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24WriterSuffixFilter$vtype _jc_javax_imageio_ImageIO__24WriterSuffixFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24WriterSuffixFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24WriterSuffixFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24WriterSuffixFilter_H_ */
